import clsx from 'clsx';
import Heading from '@theme/Heading';
import styles from './styles.module.css';

import guestsFeatureImage from '@site/static/img/guests.png';
import expensesFeatureImage from '@site/static/img/expenses.png';
import seatingFeatureImage from '@site/static/img/tables.png';
import openSourceFeatureImage from '@site/static/img/gift.png';

type FeatureItem = {
  title: string;
  imagePath: string;
  description: JSX.Element;
};

const FeatureList: FeatureItem[] = [

  {
    title: 'Guests management',
    imagePath: guestsFeatureImage,
    description: (
      <>
        Manage your guests' list, their RSVP status, as well as their dietary preferences and transportation needs.
      </>
    ),
  },
  {
    title: 'Expenses control',
    imagePath: expensesFeatureImage,
    description: (
      <>
        Configure your fixed and per-guest expenses, keeping control of the maximum and projected cost of the wedding (based on your guests' RSVP).
      </>
    ),
  },
  {
    title: 'Seating plan',
    imagePath: seatingFeatureImage,
    description: (
      <>
        Organize your guests into groups and subgroups, and let advanced algorithms suggest different seating arrangements based on the affinity between groups.
      </>
    ),
  },
];

function Feature({ title, imagePath, description }: FeatureItem) {
  return (
    <div className={clsx('col')}>
      <div className="text--center">
        <img src={imagePath} alt={title} className={styles.featureSvg} />
      </div>
      <div className="text--center padding-horiz--md">
        <Heading as="h3">{title}</Heading>
        <p>{description}</p>
      </div>
    </div>
  );
}

export default function HomepageFeatures(): JSX.Element {
  return (
    <>
      <h2>Features</h2>
      <section className={styles.features}>
        <div className="container">
          <div className="row ">
            {FeatureList.map((props, idx) => (
              <Feature key={idx} {...props} />
            ))}
          </div>
        </div>
      </section>
      <h2>Free & Open Source Software</h2>
      <section className={styles.project}>
        <p>
          This project was created to help individuals organize their own wedding, without the need to rely on proprietary software or services.
          We firmly believe that the data related to your wedding should be owned by you, and not by a third party. For that reason, our
          recommendation is that you host your own instance of Libre Wedding Planner, either at home, on your own server or on a cloud provider
          of your choice.
        </p>
        <p>
          However, we are well aware that most users don't have the technical skills or resources to host their own instance. For that reason,
          we are working on a hosted version of Libre Wedding Planner you will be able to use <em>as a service</em> for an affordable fee. Still, we encourage you to
          not use this service if you can host your own instance. We don't care, and don't need to know how much you're going to spend,
          or who your guests are.
        </p>
        <p>
          Libre Wedding Planner is free (as in freedom), open source software, licensed under the AGPLv3. You are free to download the source code, use it,
          modify it, and distribute it according to the license terms. Please, find links to the source code in the footer of this page.
        </p>
      </section>
    </>
  );
}
